@@ -14,6 +14,7 @@ class ValeriaPlugin(plugins.SingletonPlugin):
     # Declare that this class implements IConfigurer.
     plugins.implements(plugins.IConfigurer)
 
+
     def update_config(self, config):
 
         # Add this plugin's templates dir to CKAN's extra_template_paths, so
@@ -21,4 +22,10 @@ class ValeriaPlugin(plugins.SingletonPlugin):
         # 'templates' is the path to the templates dir, relative to this
         # plugin.py file.
         toolkit.add_template_directory(config, 'templates')
-        toolkit.add_public_directory(config, 'public')
\ No newline at end of file
+        toolkit.add_public_directory(config, 'public')
+        # Register this plugin's fanstatic directory with CKAN.
+        # Here, 'fanstatic' is the path to the fanstatic directory
+        # (relative to this plugin.py file), and 'example_theme' is the name
+        # that we'll use to refer to this fanstatic directory from CKAN
+        # templates.
+        toolkit.add_resource('assets', 'webassets')
\ No newline at end of file
